pitchtools.NumberedIntervalClass
================================

.. abjad-lineage:: abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass

.. autoclass:: abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.direction_number
      ~abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.direction_symbol
      ~abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.direction_word
      ~abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.from_pitch_carriers
      ~abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.number
      ~abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.__abs__
      ~abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.__eq__
      ~abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.__float__
      ~abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.__format__
      ~abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.__hash__
      ~abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.__int__
      ~abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.__ne__
      ~abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.__repr__
      ~abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.__str__

Bases
-----

- :py:class:`pitchtools.IntervalClass <abjad.tools.pitchtools.IntervalClass.IntervalClass>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.direction_number
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.direction_symbol
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.direction_word
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.number
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.from_pitch_carriers
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.__abs__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.__float__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.__int__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedIntervalClass.NumberedIntervalClass.__str__
   :noindex:
